@@ -17,7 +17,7 @@ pub const INSTRUCTION_UPDATE_SPLU_PPU_STABEL_COINS:u8=13;
 pub const INSTRUCTION_DEPOSIT_SERUM:u8=14;
 pub const INSTRUCTION_WITHDRAW_SERUM:u8=15;
 pub const INSTRUCTION_AIRDROP_TOKENS:u8=16;
-pub const INSTRUCTION_UPDATE_STATE_TEERTIARY:u8=17;
+pub const INSTRUCTION_UPDATE_STATE_SPLU_TURING_MASHINE_WITH_PARAM:u8=17;
 pub const INSTRUCTION_UPDATE_STATE_AIRDROP_ACCOUNT:u8=18;
 pub const INSTRUCTION_INITIALIZE_PORTFOLIO:u8=19;
 pub const INSTRUCTION_CREATE_INIT_PPU:u8=20;
@@ -25,7 +25,7 @@ pub const INSTRUCTION_CREATE_INIT_TURING_MASHINE:u8=38;
 pub const INSTRUCTION_UPDATE_STATE_INITIALIZE_PPM:u8=21;
 pub const INSTRUCTION_ADD_ASSET_TO_PORTFOLIO:u8=22;
 pub const INSTRUCTION_ADD_SPLU_TO_PPU:u8=23;
-pub const INSTRUCTION_RESET_SPLU_PPU:u8=24;
+pub const INSTRUCTION_RESET_SPLU_TURING_MASHINE:u8=24;
 pub const INSTRUCTION_CREATE_INIT_NFT_ACCOUNT:u8=25;
 pub const INSTRUCTION_DEPOSIT_INTO_LP:u8=26;
 pub const INSTRUCTION_WITHDRAW_FROM_QUARRY:u8=27;
